%define oname	Eterm

%define major	%{version}
%define libname	%mklibname %{name} %{major}
%define devname	%mklibname %{name} -d

Summary:	Terminal emulator
Name:		eterm
Version:	0.9.7
Release:	%mkrel 8
License:	BSD
Group:		Terminals
URL:		https://git.enlightenment.org/apps/eterm.git
Source0:	%{oname}-%{version}.tar.gz
Source5:	http://www.eterm.org/download/%{oname}-bg-0.9.6.tar.gz
Patch0:		CVE-2021-33477.patch
#  with Fix for graphics/imlib2 update 
# imlib_strerror() has been introduced to imlib2; mangle local version.
# from http://cvsweb.netbsd.org/bsdweb.cgi/pkgsrc/x11/eterm/patches/patch-src_pixmap.c
Patch1:		patch-src_pixmap.c
Patch2:		patch-src_pixmap.h
Patch3:		eterm-0.9.6-gcc10.patch
Patch4:		eterm-0.9.6-gcc14.patch
Patch5:		eterm-c99-headers.patch
BuildRequires:	pkgconfig(imlib2)
BuildRequires:	libast-devel >= 0.5
BuildRequires:	utempter-devel
BuildRequires:	pkgconfig(x11)
BuildRequires:	twin-devel
BuildRequires:	pkgconfig(xres)
BuildRequires:	pkgconfig(xext)
BuildRequires:	pkgconfig(xmu)
BuildRequires:  groff-for-man
BuildRequires:	man
BuildRequires:	gdb
BuildRequires:	chrpath
Requires(pre):	ncurses
# needed by Etbg_update_list script
Requires(post):	diffutils
Provides:	%{oname} = %{version}-%{release}
Obsoletes:	%{oname} < %{version}-%{release}

%description
Eterm is a color vt102 terminal emulator intended as a replacement for Xterm.
It is designed with a Freedom of Choice philosophy, leaving as much power,
flexibility, and freedom as possible in the hands of the user.

It is designed to look good and work well, but takes a feature-rich approach
rather than one of minimalism while still maintaining speed and efficiency.

It works on any windowmanager/desktop environment, although it is designed
to work and integrate best with Enlightenment.

%package -n	%{libname}
Summary:	Library from Eterm (Enlightened Terminal Emulator)
Group:		Terminals

%description -n	%{libname}
Eterm is a color vt102 terminal emulator intended as a replacement for Xterm.
It is designed with a Freedom of Choice philosophy, leaving as much power,
flexibility, and freedom as possible in the hands of the user.

It is designed to look good and work well, but takes a feature-rich approach
rather than one of minimalism while still maintaining speed and efficiency.

It works on any windowmanager/desktop environment, although it is designed
to work and integrate best with Enlightenment.

This library is essential for Eterm to work.

%package -n %{devname}
Summary:	Devel files for Eterm
Group:		Development/Other
Requires:	%{libname} = %{version}-%{release}
Obsoletes:	%{oname}-devel < %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	%{oname}-devel = %{version}-%{release}

%description -n %{devname}
Eterm is a color vt102 terminal emulator intended as a replacement for Xterm.
It is designed with a Freedom of Choice philosophy, leaving as much power,
flexibility, and freedom as possible in the hands of the user.

It is designed to look good and work well, but takes a feature-rich approach
rather than one of minimalism while still maintaining speed and efficiency.

It works on any windowmanager/desktop environment, although it is designed
to work and integrate best with Enlightenment.

This package provides the necessary development libraries and include files
to allow you to develop or compile programs that needs Eterm, though no such
program has existed so far.

%prep
%setup -q -a5 -n %{oname}-%{version}
%patch -P 0 -p1
%patch -P 1 -p0
%patch -P 2 -p0
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 5 -p1

# fix rpmlint warning
# change character encoding
mv ChangeLog ChangeLog.old
iconv -f ISO-8859-1 -t UTF8 -o ChangeLog ChangeLog.old

# patch1 also sets $TERM = xterm for all themes,
# do that here since patch1 is not applied
find themes/ -name 'theme.cfg.in' -print0 | xargs -0 -r perl -pi -e 's/term_name Eterm/term_name xterm/'

%build
autoreconf -fi
%configure \
  --enable-etwin \
  --enable-escreen-fx \
  --enable-profile \
  --enable-trans \
  --with-backspace=bs \
  --disable-mmx \
  --enable-utmp \
  --with-delete=execute \
  --enable-auto-encoding \
  --enable-multi-charset \
  --enable-xim \
  --enable-greek \
  --disable-static

%make_build

%install
%make_install

mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=Eterm
Comment=Enlightened Terminal Emulator
Exec=%{oname}
Icon=terminals_section
Terminal=false
Type=Application
Categories=System;TerminalEmulator;
EOF

#for %%ghost file
touch %{buildroot}%{_datadir}/%{oname}/pix/pixmaps.list.old

# fiw rpmlint warning
# remove rpath
chrpath -d %{buildroot}%{_bindir}/{Esetroot,Eterm}

#we don't want these
rm -rf %{buildroot}%{_libdir}/*.la

%post
%{_bindir}/Etbg_update_list %{_datadir}/%{oname}/pix/

%files
%defattr(-, root, root,0755)
%doc ChangeLog README ReleaseNotes doc/Eterm_reference.html doc/README.Escreen
%{_bindir}/*
%dir %{_datadir}/%{oname}
%{_datadir}/%{oname}/gdb.scr
%config(noreplace) %{_datadir}/%{oname}/themes
%dir %{_datadir}/%{oname}/pix
%ghost %{_datadir}/%{oname}/pix/pixmaps.list.old
%{_datadir}/%{oname}/pix/tile
%{_datadir}/%{oname}/pix/scale
%{_datadir}/%{oname}/pix/*.png
%{_datadir}/%{oname}/pix/pixmaps.list
%{_mandir}/man1/Eterm.1.*
%{_datadir}/applications/%{name}.desktop

%files -n %{libname}
%{_libdir}/lib%{oname}-%{major}.so

%files -n %{devname}
%{_libdir}/lib%{oname}.so


%changelog
* Sat Oct 26 2024 eatdirt <eatdirt> 0.9.7-8.mga10
+ Revision: 2111342
- Disabling mmx and removing obsoleted obsoletes

* Tue Oct 01 2024 ns80 <ns80> 0.9.7-7.mga10
+ Revision: 2102281
- add patches from Fedora to fix building with GCC 14

* Fri Mar 03 2023 papoteur <papoteur> 0.9.7-6.mga9
+ Revision: 1946728
- fix build with new imlib2

* Thu Mar 31 2022 umeabot <umeabot> 0.9.7-5.mga9
+ Revision: 1836251
- Mageia 9 Mass Rebuild

* Thu Jul 08 2021 ns80 <ns80> 0.9.7-4.mga9
+ Revision: 1735161
- add Debian patch for CVE-2021-33477 (mga#28939)

* Thu Feb 13 2020 umeabot <umeabot> 0.9.7-3.mga8
+ Revision: 1512098
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 0.9.7-2.mga7
+ Revision: 1297626
- Mageia 7 Mass Rebuild
+ kekepower <kekepower>
- Use new make macros

* Tue Nov 29 2016 eatdirt <eatdirt> 0.9.7-1.mga6
+ Revision: 1070995
- Upgrade to version 0.9.7

* Tue Feb 02 2016 umeabot <umeabot> 0.9.6-10.mga6
+ Revision: 932831
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.9.6-9.mga5
+ Revision: 746886
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.9.6-8.mga5
+ Revision: 679035
- Mageia 5 Mass Rebuild

* Sat Sep 06 2014 luigiwalser <luigiwalser> 0.9.6-7.mga5
+ Revision: 672788
- rebuild for libutempter

* Sat Oct 19 2013 umeabot <umeabot> 0.9.6-6.mga4
+ Revision: 522492
- Mageia 4 Mass Rebuild

* Sun Mar 10 2013 rtp <rtp> 0.9.6-5.mga3
+ Revision: 402059
- enable mmx only on x86/x86_64 platforms

* Fri Jan 11 2013 umeabot <umeabot> 0.9.6-4.mga3
+ Revision: 349747
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Aug 29 2012 eatdirt <eatdirt> 0.9.6-3.mga3
+ Revision: 285403
- Remove conflicts with ncurses-extraterms

* Mon Nov 07 2011 wally <wally> 0.9.6-2.mga2
+ Revision: 164971
- fix post scriptlets (mga#3280)
- fix file list
- fix some rpmlint warnings
  * character encoding
  * rpath

* Tue Jun 14 2011 wally <wally> 0.9.6-1.mga2
+ Revision: 106156
- rename package to eterm
- new version 0.9.6
- fixes CVE-2011-0409
- fixes CVE-2011-0768
- fix libification
- disable static build

* Sun May 15 2011 pterjan <pterjan> 0.9.5-13.mga1
+ Revision: 98978
- Rebuild for fixed find-requires

* Mon Apr 25 2011 wally <wally> 0.9.5-12.mga1
+ Revision: 90254
- drop P1, unused since forever

* Mon Apr 25 2011 wally <wally> 0.9.5-11.mga1
+ Revision: 90241
- raise rel so package gets updated when updating from Mdv
- fix desktop file name (mga#954)
- fix desktop file
- unpack patch
- more .spec cleaning

* Tue Apr 19 2011 ennael <ennael> 0.9.5-1.mga1
+ Revision: 88286
- clean spec file
+ steletch <steletch>
- One spec typo was left
- More cleanup of the spec file
- Clean spec file
- imported package Eterm

